.. _module_ext_client_core:

Core
====

This section contains module documentation of Client core modules. 

.. toctree::
   :maxdepth: 1
   
   core/autocompleter
   core/colorizer
   core/config
   core/editor
   core/explorer
   core/filetab
   core/formatter
   core/gui
   core/help
   core/logger
   core/notebook
   core/plugin
   core/pluginmanager
   core/tkimport
   core/tooltip
   core/translator
   core/utils
   core/yoda_tree